@@ -1,6 +1,7 @@
 #!/usr/bin/python3
 """Low level signing library for FlureeDB signatures"""
 import json
+from enum import Enum
 import random
 import time
 from time import mktime
@@ -26,21 +27,75 @@ def _to_hex(x):
     string
         Hex representation of the binary string.
     """
+    if isinstance(x, bytes):
+        return x.hex()
     return "".join([hex(ord(c))[2:].zfill(2) for c in x])
 
 
+class BlockChain(Enum):
+    """Enum for different bitcoin like chains"""
+    BITCOIN = 1
+    FLUREEDB = 2
+    DASH = 3
+    DOGECOIN = 4
+    LITECOIN = 5
+    NAMECOIN = 6
+    ZCASH = 7
+
+
+_net_id_map = {
+  BlockChain.BITCOIN: b"\x00",
+  BlockChain.FLUREEDB: b"\x0f\x02",
+  BlockChain.DASH: b"\x4c",
+  BlockChain.DOGECOIN: b"\x1e",
+  BlockChain.LITECOIN: b"\x30",
+  BlockChain.NAMECOIN: b"\x34",
+  BlockChain.ZCASH: b"\x1c\xb8"
+}
+
+
+def pubkey_to_address(pubkey, chain):
+    """Get FlureeDB address from pubkey
+
+    NOTE: This functionality should probably (mostly) be in the ellipticcurve library.
+
+    Parameters
+    ----------
+    pubkey : ellipticcurve.publicKey.PublicKey
+             ECDSA pubkey
+    chain : BlockChain
+             The blockchain we are calculating the address for
+
+    Returns
+    -------
+    string
+        Base58 encoded FlureeDB address
+    """
+    x = pubkey.point.x.to_bytes(32, byteorder='big')
+    yred = (2 + pubkey.point.y % 2).to_bytes(1, byteorder='big')
+    key = yred + x
+    hash1 = hashlib.sha256()
+    hash2 = hashlib.new('ripemd160')
+    hash1.update(key)
+    hash2.update(hash1.digest())
+    core = _net_id_map[chain] + hash2.digest()
+    hash3 = hashlib.sha256()
+    hash4 = hashlib.sha256()
+    hash3.update(core)
+    hash4.update(hash3.digest())
+    return base58.b58encode(core + hash4.digest()[:4]).decode()
+
+
 class DbSigner:
     """Low level signer class for signing FlureeDB transactions and queries"""
     # pylint: disable=too-many-arguments
-    def __init__(self, privkey, address, database, validity=120, fuel=1000):
+    def __init__(self, privkey, database, validity=120, fuel=1000):
         """Constructor for DbSigner
 
         Parameters
         ----------
         privkey : string
                   Hex or base58 encoded signing key.
-        address : string
-                  Key-id of the signing key.
         database : string
                    Network/Db string for the database to use.
         validity: int
@@ -50,9 +105,11 @@ class DbSigner:
         """
         if len(privkey) != 64:
             privkey = base58.b58decode(privkey).hex()
-        self.private_key = privateKey.PrivateKey.fromString(bytes.fromhex(privkey))
+        # Old line from 1.0.3
+        # self.private_key = privateKey.PrivateKey.fromString(bytes.fromhex(privkey))
+        self.private_key = privateKey.PrivateKey.fromString(privkey)
         self.public_key = self.private_key.publicKey()
-        self.auth_id = address
+        self.auth_id = pubkey_to_address(self.public_key, BlockChain.FLUREEDB)
         self.database = database
         self.validity = validity
         self.fuel = fuel
@@ -73,7 +130,7 @@ class DbSigner:
         sig = ecdsa.Ecdsa.sign(datastring, self.private_key)
         derstring = sig.toDer(withRecoveryId=True)
         hexder = _to_hex(derstring)
-        command = dict()
+        command = {}
         command["cmd"] = datastring
         command["sig"] = hexder
         return command
@@ -109,7 +166,7 @@ class DbSigner:
         dict
             Python dict with command and signature fields.
         """
-        obj = dict()
+        obj = {}
         obj["type"] = "tx"
         obj["tx"] = transaction
         obj["db"] = self.database
@@ -157,7 +214,7 @@ class DbSigner:
         sig = ecdsa.Ecdsa.sign(signingstring, self.private_key)
         derstring = sig.toDer(withRecoveryId=True)
         hexder = _to_hex(derstring)
-        headers = dict()
+        headers = {}
         headers["Content-Type"] = "application/json"
         headers["X-Fluree-Date"] = mydate
         headers["Signature"] = \
